@@ -101,12 +101,8 @@ local function typesetAST (options, content)
          else
             seenCommandWithoutArg = true
          end
-      elseif ast.id == "content" or (not ast.command and not ast.id) then
-         -- Due to the way it is implemented, the SILE-inputter may generate such
-         -- nodes in the AST. It's poorly documented, so it's not clear why they
-         -- are even kept there (esp. the "content" nodes), but anyhow, as
-         -- far as autodoc is concerned for presentation purposes, just
-         -- recurse into them.
+      elseif not ast.command and not ast.id then
+         -- Mere list of nodes
          typesetAST(options, ast)
       else
          SU.error("Unrecognized AST element, type " .. type(ast))
@@ -119,6 +115,7 @@ function package:_init (options)
    self:loadPackage("inputfilter")
    self:loadPackage("rules")
    self:loadPackage("raiselower")
+   self:loadPackage("verbatim")
    if options then
       pl.tablex.update(theme, options)
    end
@@ -375,39 +372,38 @@ function package:registerCommands ()
    -- Homogenizing the appearance of blocks of code
    self:registerCommand("autodoc:codeblock", function (_, content)
       SILE.typesetter:leaveHmode()
+      local lskip = SILE.settings:get("document.lskip") or SILE.types.node.glue()
+      local rskip = SILE.settings:get("document.rskip") or SILE.types.node.glue()
       SILE.settings:temporarily(function ()
          -- Note: We avoid using the verbatim environment and simplify things a bit
          -- (and try to better enforce novbreak points of insertion)
          SILE.call("verbatim:font")
+         SILE.call("language", { main = "und" })
          -- Rather than absolutizing 4 different values, just do it once and cache it
+         local bs = SILE.types.measurement("1bs"):absolute()
          local ex = SILE.types.measurement("1ex"):absolute()
          local pushline = function ()
             colorWrapper("note", function ()
                SILE.call("novbreak")
-               SILE.typesetter:pushVglue(ex)
+               SILE.typesetter:pushVglue(-bs)
                SILE.call("novbreak")
                SILE.call("fullrule", { thickness = "0.5pt" })
                SILE.call("novbreak")
-               SILE.typesetter:pushVglue(-ex)
+               SILE.typesetter:pushVglue(-bs-ex)
                SILE.call("novbreak")
             end)
          end
          SILE.settings:set("typesetter.parseppattern", "\n")
          SILE.settings:set("typesetter.obeyspaces", true)
+         SILE.settings:set("document.lskip", SILE.types.node.glue(lskip.width.length))
+         SILE.settings:set("document.rskip", SILE.types.node.glue(rskip.width.length))
          SILE.settings:set("document.parindent", SILE.types.node.glue())
-         SILE.settings:set("document.parskip", SILE.types.node.vglue(0.3 * ex))
-         SILE.settings:set("document.baselineskip", SILE.types.node.glue(2.3 * ex))
+         SILE.settings:set("document.parskip", SILE.types.node.vglue())
          SILE.settings:set("document.spaceskip", SILE.types.length("1spc"))
          SILE.settings:set("shaper.variablespaces", false)
-         SILE.settings:set("document.language", "und")
          colorWrapper("codeblock", function ()
-            SILE.call("skip", { height = ex })
             pushline()
-            SILE.typesetter:pushVglue(SILE.settings:get("document.parskip"))
-            SILE.call("novbreak")
             SILE.process(content)
-            SILE.call("novbreak")
-            SILE.typesetter:pushVglue(SILE.settings:get("document.parskip"))
             pushline()
          end)
          SILE.typesetter:leaveHmode()
