@@ -13,20 +13,22 @@ function package:registerCommands ()
    self:registerCommand("verbatim", function (_, content)
       SILE.typesetter:pushVglue(6)
       SILE.typesetter:leaveHmode()
+      local lskip = SILE.settings:get("document.lskip") or SILE.types.node.glue()
+      local rskip = SILE.settings:get("document.rskip") or SILE.types.node.glue()
       SILE.settings:temporarily(function ()
+         SILE.call("verbatim:font")
+         SILE.call("language", { main = "und" })
          SILE.settings:set("typesetter.parseppattern", "\n")
          SILE.settings:set("typesetter.obeyspaces", true)
-         SILE.settings:set("document.rskip", SILE.types.node.glue("0 plus 10000pt"))
-         SILE.settings:set("document.parindent", SILE.types.node.glue("0"))
-         SILE.settings:set("document.baselineskip", SILE.types.node.vglue("0"))
-         SILE.settings:set("document.lineskip", SILE.types.node.vglue("2pt"))
-         SILE.call("verbatim:font")
+         SILE.settings:set("document.lskip", SILE.types.node.glue(lskip.width.length))
+         SILE.settings:set("document.rskip", SILE.types.node.glue(rskip.width.length))
+         SILE.settings:set("document.parindent", SILE.types.node.glue())
+         SILE.settings:set("document.parskip", SILE.types.node.vglue())
          SILE.settings:set("document.spaceskip", SILE.types.length("1spc"))
          SILE.settings:set("shaper.variablespaces", false)
-         SILE.settings:set("document.language", "und")
          SILE.process(content)
+         SILE.typesetter:leaveHmode()
       end)
-      SILE.typesetter:leaveHmode()
    end, "Typesets its contents in a monospaced font.")
 
    self:registerCommand("obeylines", function (_, content)
